@@ -6,7 +6,7 @@
  *
  * wolfSSL is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * wolfSSL is distributed in the hope that it will be useful,
@@ -189,7 +189,7 @@ extern "C" {
 #undef NO_MD4
 #define NO_MD4
 #undef NO_MD5
-/* #undef NO_MD5 */
+#define NO_MD5
 #undef NO_OLD_RNGNAME
 /* #undef NO_OLD_RNGNAME */
 #undef NO_OLD_SHA_NAMES
@@ -197,7 +197,7 @@ extern "C" {
 #undef NO_OLD_SSL_NAMES
 /* #undef NO_OLD_SSL_NAMES */
 #undef NO_OLD_TLS
-/* #undef NO_OLD_TLS */
+#define NO_OLD_TLS
 #undef NO_OLD_WC_NAMES
 /* #undef NO_OLD_WC_NAMES */
 #undef NO_PKCS12
